package com.abi.qms.platform.service.impl;

import com.abi.qms.platform.dao.entity.BaseActive;
import com.abi.qms.platform.dao.mapper.BaseActiveMapper;
import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.GetActiveRes;
import com.abi.qms.platform.dto.res.ListActiveRes;
import com.abi.qms.platform.infrastructure.util.AssertUtil;
import com.abi.qms.platform.infrastructure.util.PageUtil;
import com.abi.qms.platform.service.ActiveService;
import com.abi.task.common.utils.PojoConverterUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;

/**
 * <p>
 * 活动
 * </p>
 *
 * @author Andy.Tan
 */
@Service
public class ActiveServiceImpl implements ActiveService {

    @Autowired
    private BaseActiveMapper baseActiveMapper;


    /**
     * 新增活动
     */
    @Override
    public void addActive(AddActiveReq req){
        //校验入参
        //TODO

        //1-新增
        BaseActive active = new BaseActive();
        active.setActiveCode(req.getActiveCode());
        active.setActiveName(req.getActiveName());
        active.setActiveType(req.getActiveType());
        active.setAuditStatus(req.getAuditStatus());
        active.setApplyUserId(req.getApplyUserId());
        active.setApplyUserName(req.getApplyUserName());
        active.setAuditUserId(req.getAuditUserId());
        active.setAuditUserName(req.getAuditUserName());
        active.setBeginTime(req.getBeginTime());
        active.setEndTime(req.getEndTime());
        active.setBrandCode(req.getBrandCode());
        active.setSubBrandCode(req.getSubBrandCode());
        active.setActiveUrl(req.getActiveUrl());
        baseActiveMapper.insert(active);

    }

    /**
     * 编辑活动
     */
    @Override
    public void updateActive(UpdateActiveReq req){

        //1-查询活动
        BaseActive active = baseActiveMapper.selectById(req.getId());
        AssertUtil.isNull(active,"活动不存在");

        //2-修改活动
        active.setActiveCode(req.getActiveCode());
        active.setActiveName(req.getActiveName());
        active.setActiveType(req.getActiveType());
        active.setAuditStatus(req.getAuditStatus());
        active.setApplyUserId(req.getApplyUserId());
        active.setApplyUserName(req.getApplyUserName());
        active.setAuditUserId(req.getAuditUserId());
        active.setAuditUserName(req.getAuditUserName());
        active.setBeginTime(req.getBeginTime());
        active.setEndTime(req.getEndTime());
        active.setBrandCode(req.getBrandCode());
        active.setSubBrandCode(req.getSubBrandCode());
        active.setActiveUrl(req.getActiveUrl());
        baseActiveMapper.updateById(active);

    }

    /**
     * 分页查询活动
     */
    @Override
    public ListActiveRes listActive(ListActiveReq req){

        //1-拼接条件
        QueryWrapper<BaseActive> activeQw = new QueryWrapper<>();
        //activeQw.like(StringUtils.isNotBlank(req.getXxx()), "xxx_xxx", "%" + req.getXxx() + "%");
        //activeQw.eq(req.getXxx2() != null, "xxx_xxx2", req.getXxx2());

        //2-分页查询
        IPage<BaseActive> iPage = baseActiveMapper.selectPage(PageUtil.createPage(req), activeQw);
        List<BaseActive> activeList = iPage.getRecords();

        //封装出参
        ListActiveRes res = new ListActiveRes();
        //放入分页信息
        PageUtil.copyPageInfo(res, iPage);
        //放入出参列表
        List<ListActiveRes.ActiveBean> activeBeanList = PojoConverterUtils.copyList(activeList, ListActiveRes.ActiveBean.class);
        res.setActiveBeanList(activeBeanList);

        return res;

    }

    /**
     * 查询活动明细
     */
    @Override
    public GetActiveRes getActive(GetActiveReq req){

        //1-查询活动对象
        BaseActive active = baseActiveMapper.selectById(req.getId());
        AssertUtil.isNull(active, "活动不存在");

        //转化出参
        GetActiveRes res = PojoConverterUtils.copy(active, GetActiveRes.class);

        return res;

    }

    /**
     * 活动启用
     */
    @Override
    public void enableActive(EnableActiveReq req){
        List<Long> ids = req.getIds();

        //循环启用
        for (Long id : ids) {
            //1-查询活动对象
            BaseActive active = baseActiveMapper.selectById(id);
            AssertUtil.isNull(active, "活动不存在");

//            if (!ValidEnum.NOT_VALID.is(active.getValid())) {
//                continue;
//            }
//
//            //2-修改状态
//            active.setValid(ValidEnum.VALID.getCode());
//            baseActiveMapper.updateById(active);
        }
    }

    /**
     * 活动禁用
     */
    @Override
    public void disableActive(DisableActiveReq req){
        List<Long> ids = req.getIds();

        //循环禁用
        for (Long id : ids) {
            //1-查询活动对象
            BaseActive active = baseActiveMapper.selectById(id);
            AssertUtil.isNull(active, "活动不存在");

//            if (!ValidEnum.VALID.is(active.getValid())) {
//                return;
//            }
//
//            //2-修改状态
//            active.setValid(ValidEnum.NOT_VALID.getCode());
//            baseActiveMapper.updateById(active);
        }
    }

}
